@@ -1,6 +1,7 @@
 from __future__ import annotations
 from ..Decorators import validate
-from typing import Any, Tuple, Iterable
+from ..Typing import Any, Tuple, Iterable, Union
+from ..Functions import isoftype
 
 
 class Node:
@@ -82,7 +83,3 @@ class Queue:
 
 class LinkedList:
     pass
-
-
-class Graph:
-    pass
